==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/DataProviderData.java <==
package com.example.model;

/**
 * Model for DataProvider
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.329Z")
@io.swagger.annotations.ApiModel(value = "DataProviderData", description = "Model for DataProvider")
@javax.xml.bind.annotation.XmlRootElement(name = "DataProviderData")
public class DataProviderData implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private com.example.model.DataProvider dataconnecT = null;
	private com.example.model.DataProvider greeniD = null;
	private com.example.model.DataProvider idmatriX = null;
	
	/**
	 * Model for DataConnect
	 */
	public DataProviderData dataconnecT(com.example.model.DataProvider dataconnecT) {
		setDataconnecT(dataconnecT);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "Model for DataConnect")
	@com.fasterxml.jackson.annotation.JsonProperty("DATA_CONNECT")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public com.example.model.DataProvider getDataconnecT() {
		return this.dataconnecT;
	}
	public void setDataconnecT(com.example.model.DataProvider dataconnecT) {
		this.dataconnecT = dataconnecT;
	}
	
	/**
	 * Model for DataConnect
	 */
	public DataProviderData greeniD(com.example.model.DataProvider greeniD) {
		setGreeniD(greeniD);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "Model for DataConnect")
	@com.fasterxml.jackson.annotation.JsonProperty("GREEN_ID")
	@javax.validation.Valid
	public com.example.model.DataProvider getGreeniD() {
		return this.greeniD;
	}
	public void setGreeniD(com.example.model.DataProvider greeniD) {
		this.greeniD = greeniD;
	}
	
	/**
	 * Model for DataConnect
	 */
	public DataProviderData idmatriX(com.example.model.DataProvider idmatriX) {
		setIdmatriX(idmatriX);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "Model for DataConnect")
	@com.fasterxml.jackson.annotation.JsonProperty("ID_MATRIX")
	@javax.validation.Valid
	public com.example.model.DataProvider getIdmatriX() {
		return this.idmatriX;
	}
	public void setIdmatriX(com.example.model.DataProvider idmatriX) {
		this.idmatriX = idmatriX;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		DataProviderData dataProviderData = (DataProviderData) o;
		return java.util.Objects.equals(this.dataconnecT, dataProviderData.dataconnecT)
				&& java.util.Objects.equals(this.greeniD, dataProviderData.greeniD)
				&& java.util.Objects.equals(this.idmatriX, dataProviderData.idmatriX);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.dataconnecT, this.greeniD, this.idmatriX);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class DataProviderData {\n");
		
		sb.append("    dataconnecT: ").append(toIndentedString(this.dataconnecT)).append("\n");
		sb.append("    greeniD: ").append(toIndentedString(this.greeniD)).append("\n");
		sb.append("    idmatriX: ").append(toIndentedString(this.idmatriX)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/DataProviderData.java <==
package com.example.model;

/**
 * Model for DataProvider
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.443Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "DataProviderData", description = "Model for DataProvider")
@javax.xml.bind.annotation.XmlRootElement(name = "DataProviderData")
public class DataProviderData implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private com.example.model.DataProvider dataconnecT = null;
	private com.example.model.DataProvider greeniD = null;
	private com.example.model.DataProvider idmatriX = null;
	
	/**
	 * Model for DataConnect
	 */
	public DataProviderData dataconnecT(com.example.model.DataProvider dataconnecT) {
		setDataconnecT(dataconnecT);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "DATA_CONNECT", description = "Model for DataConnect")
	@com.fasterxml.jackson.annotation.JsonProperty("DATA_CONNECT")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public com.example.model.DataProvider getDataconnecT() {
		return this.dataconnecT;
	}
	public void setDataconnecT(com.example.model.DataProvider dataconnecT) {
		this.dataconnecT = dataconnecT;
	}
	
	/**
	 * Model for DataConnect
	 */
	public DataProviderData greeniD(com.example.model.DataProvider greeniD) {
		setGreeniD(greeniD);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "GREEN_ID", description = "Model for DataConnect")
	@com.fasterxml.jackson.annotation.JsonProperty("GREEN_ID")
	@javax.validation.Valid
	public com.example.model.DataProvider getGreeniD() {
		return this.greeniD;
	}
	public void setGreeniD(com.example.model.DataProvider greeniD) {
		this.greeniD = greeniD;
	}
	
	/**
	 * Model for DataConnect
	 */
	public DataProviderData idmatriX(com.example.model.DataProvider idmatriX) {
		setIdmatriX(idmatriX);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "ID_MATRIX", description = "Model for DataConnect")
	@com.fasterxml.jackson.annotation.JsonProperty("ID_MATRIX")
	@javax.validation.Valid
	public com.example.model.DataProvider getIdmatriX() {
		return this.idmatriX;
	}
	public void setIdmatriX(com.example.model.DataProvider idmatriX) {
		this.idmatriX = idmatriX;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		DataProviderData dataProviderData = (DataProviderData) o;
		return java.util.Objects.equals(this.dataconnecT, dataProviderData.dataconnecT)
				&& java.util.Objects.equals(this.greeniD, dataProviderData.greeniD)
				&& java.util.Objects.equals(this.idmatriX, dataProviderData.idmatriX);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.dataconnecT, this.greeniD, this.idmatriX);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class DataProviderData {\n");
		
		sb.append("    dataconnecT: ").append(toIndentedString(this.dataconnecT)).append("\n");
		sb.append("    greeniD: ").append(toIndentedString(this.greeniD)).append("\n");
		sb.append("    idmatriX: ").append(toIndentedString(this.idmatriX)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
